------------------------------------------------------------------------------
-- title        nano-cpld.vhd
-- Version      1
-- Date         2007/01/11
-- 
-- Copyright    Copyright (c) 2007
-- Author       Stephan Schirrmann
-- Company      Simple Solutions
--
-- Description:
--   Init and boot functions for CPLD on Zefant-nano
--
-- Known restrictions:
--
---------------------------------------------------------------------------


library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity nano_cpld is
  port ( 
    -- Connections to FPGA
    fpga_io_e16_l17n_1 : in  STD_LOGIC;

    -- Flash Memory
    fl_a               : out std_logic_vector(25 downto 0);
    fl_byte_n          : out std_logic;

    -- User IO
    cpld_led           : out std_logic;
    switch             : in  std_logic;

    -- FPGA dedicated signals
    fpga_m             : out std_logic_vector(2 downto 0);
    fpga_done          : in  std_logic

	);
end nano_cpld;

architecture Behavioral of nano_cpld is

begin

  -- Flash: Use 16bit mode only
  fl_a(0)            <= fpga_io_e16_l17n_1;
  fl_a(24)           <= 'Z';
  fl_a(25)           <= '0';
  fl_byte_n          <= '1';

  -- FPGA boot related signals
  fpga_m             <= "101" when switch = '1' else "010";  -- switch=off=high => JTAG mode, switch=on=low => BPI mode
  cpld_led           <= fpga_done;


end Behavioral;

